@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 import sys
 sys.path.append(gwp.get_system_plugins_dir())
 ##import vp_utils
@@ -14,7 +13,7 @@ class Quark(gwp.Plugin):
     author_name = "Cristian Abalos"
     author_email = "abalosc@gmail.com"
     desc_short = _("Help in the resources management")
-    desc_long = ""
+    desc_long = _("Quark provee una serie de informes del manejo de recursos por planeta. Hace recomendaciones de los posibles cambios para mejorar la situacion de los mismos.\nLos reportes que brinda son:\nEstado de los colonos y nativos el siguiente turno (Unhappy, Riot, etc) en funcion de la felicidad. \nCantidad de colonos necesarios para: \nCobrar el maximo de impuestos a los nativos.\nObtener el maximo de supplies en planetas con Bovinoides.\nConstruir las edificaciones necesarias (fabricas, minas, puestos de defensa).\nBeneficios obtenidos al terraformar el planeta para aumentar el limite de colonos que soporta.")
     license = "GPL"
     hotkey = 'q'
 
@@ -69,6 +68,18 @@ class Quark(gwp.Plugin):
         self.report_verify_colonists(p)
         self.report_verify_temperature(p) # Ve si conviene Terraformar
 
+        # PRUEBAS CONSTRUCIONES
+        
+        #pid = p.get_id()
+        #pq = self.pl_qdata[pid]
+
+        #if pq['tipo_quark'] ==  self.quark_utils.TIPO_MINERO:
+            # 200 clanes
+        #    self.natt = self.natt + "\n"
+        #    self.quark_set_icon(self.quark_utils.PRIORIDAD_AVISO_MEDIO, self.natt)
+        #elif pq['tipo_quark'] ==  self.quark_utils.TIPO_COMUN:
+            # 100
+
     #--------------------------------------------------------------------------
     def calculate_future_happyness_natives(self, p):
         """Devuelve el valor de happyness del siguiente turno"""
@@ -444,6 +455,9 @@ class Quark(gwp.Plugin):
         if self.na and (event == 'planet-selected'):
             self.na.add_notification(self.quark_icon)
             self.na_report_generate(objeto)
+            pid = objeto.get_id()
+            self.planet_load_data(pid)
+            
             #for planeta in self.pl:
             #    if planeta.get_id() == pid:
             #        self.na_report_generate(objeto)
@@ -454,7 +468,7 @@ class Quark(gwp.Plugin):
             self.na.remove_notification(self.quark_icon)
 
     #--------------------------------------------------------------------------    
-    def quark_set_report(self, p):
+    def quark_set_report(self):
         """Realiza todos los chequeos para mostrar el reporte en la ventana de
         existir algo que informar."""
         self.textbuffer = self.tv_notification.get_buffer()
@@ -595,7 +609,7 @@ class Quark(gwp.Plugin):
         self.store_minerals.append(fila)
         
         ## renderer.set_property('background','green')
-        self.quark_set_report(p)
+        self.quark_set_report()
 
     #--------------------------------------------------------------------------
     def main_cb(self, widget, data=None):
