@@ -1,6 +1,6 @@
 /*
  *  Gnome War Pad: A VGA Planets Client for Gnome
- *  Copyright (C) 2002-2004 Lucas Di Pentima <lucas@lunix.com.ar>
+ *  Copyright (C) 2002-2005 Lucas Di Pentima <lucas@lunix.com.ar>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,6 +17,19 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+/** \file
+    $Source: /usr/local/cvs-publico/GWP/gwp/src/callbacks.c,v $ 
+    $Revision: 1.102 $
+    
+    $Log: callbacks.c,v $
+    Revision 1.102  2005/07/05 02:36:11  ldipenti
+    Feature: game property editor improved
+
+    Revision 1.101  2005/05/31 13:17:38  ldipenti
+    Feature: Added CVS metadata on source files
+
+*/
+
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -42,7 +55,7 @@
 #include "message-reader.h"
 #include "gwp-py-functions.h"
 #include "vcr.h"
-
+#include "vp_maketurn.h"
 
 gboolean
 starchart_event_key                    (GtkWidget       *widget,
@@ -259,20 +272,22 @@ starchart_event_pointer_motion         (GtkWidget       *widget,
   return FALSE;
 }
 
-void on_game_mgr_game_dir_changed (GtkEditable *editable,
-				   gpointer user_data)
+/**
+ * Callback called when game directory setting changes.
+ *
+ * When editing game's properties, if the user change the
+ * game directory prefix, this function is called.
+ */
+void 
+on_game_mgr_game_dir_changed (GtkEditable *editable,
+			      gpointer user_data)
 {
-  GtkEntry *race_name_entry;
   char *dir;
   GtkWidget *btn_unpack = lookup_widget("game_mgr_btn_unpack");
 
   dir = gtk_editable_get_chars(editable, 0, -1);
   game_mgr_update_race_list(dir);
 
-  /* Clear the race name on the entry */
-  race_name_entry = (GtkEntry *) lookup_widget("game_mgr_entry_race_name");
-  gtk_entry_set_text(race_name_entry, "");
-
   /* Disable 'Unpack' Button */
   gtk_widget_set_sensitive(btn_unpack, FALSE);
 }
@@ -377,13 +392,13 @@ void on_game_mgr_button_cancel_clicked (GtkWidget *widget,
 }
 
 /* Get the race number and assign it to the race name field */
-void on_game_mgr_properties_race_list_row_activated (GtkWidget *widget,
-						     gpointer user_data)
+void 
+on_game_mgr_properties_race_list_row_activated (GtkWidget *widget,
+						gpointer   user_data)
 {
   GtkTreeView *race_l = NULL;
   GtkTreeSelection *sel = NULL;
   GtkTreeModel *model = NULL;
-  GtkEntry *race_name_entry = NULL;
   GtkTreeIter iter;
   gint *race = NULL;
   gchar *dir = NULL;
@@ -399,13 +414,9 @@ void on_game_mgr_properties_race_list_row_activated (GtkWidget *widget,
   race = g_malloc(sizeof(gint));
   gtk_tree_model_get(model, &iter, 1, race, -1);
 
-  /* Copy the race name on the entry */
-  race_name_entry = (GtkEntry *) lookup_widget("game_mgr_entry_race_name");
-  gtk_entry_set_text(race_name_entry, race_get_name(*race));
-
   /* Bind its number (the really important data) */
-  g_object_set_data(G_OBJECT(race_name_entry),
-		      "race_number", race);
+  g_object_set_data(G_OBJECT(race_l),
+		    "race_number", race);
 
   /* Check if it's neccesary to activate the 'unpack' button */
   dir = gnome_file_entry_get_full_path((GnomeFileEntry *)
@@ -454,12 +465,11 @@ void on_ships_list_cursor_changed (GtkWidget *widget,
 void on_game_mgr_edit_game(GtkWidget *widget,
 			   gpointer user_data)
 {
-  GtkWidget *iconlist = NULL;
+  GtkWidget *iconlist = lookup_widget("game_mgr_iconlist");
   GtkWidget *ok_button = lookup_widget("game_mgr_button_ok");
   GwpGameState *state = NULL;
   GList *selections = NULL;
 
-  iconlist = lookup_widget("game_mgr_iconlist");
   selections = gnome_icon_list_get_selection(GNOME_ICON_LIST(iconlist));
   if(selections) {
     state = (GwpGameState *) 
@@ -605,18 +615,19 @@ void on_about_activate(GtkWidget *widget)
       "Sven Wergandt <summ@gmx.de>",
       "Cristian Abalos <abalosc@yahoo.com.ar>",
       "Nicolas Cesar <ncesar@lunix.com.ar>",
+      "Franois Orieux <francois@orieux.eu.org>",
       NULL
     };
     const gchar *documenters[] = {
       "Lucas Di Pentima <lucas@lunix.com.ar>",
       NULL
     };
-    const gchar *translators = "Lucas Di Pentima <lucas@lunix.com.ar> (Spanish)\nStefan Reuther <streu@gmx.de> (German)\nDavid Botha <fermier@gmx.co.uk> (French)\nCarlos Paulino <freechgp@gmail.com> (Brazilian Portuguese)";
+    const gchar *translators = "Lucas Di Pentima <lucas@lunix.com.ar> (Spanish)\nStefan Reuther <streu@gmx.de> (German)\nFranois Orieux <francois@orieux.eu.org> (French)\nCarlos Paulino <chgp@minaslivre.org> (Brazilian Portuguese)";
 
     about_gwp = gnome_about_new(PACKAGE_NAME,
 				PACKAGE_VERSION,
 				_("(C) 2002-2005 Lucas Di Pentima\nThis software is released under the GNU GPL License"),
-				_("A VGA Planets client for the GNOME platform.\nhttp://www.lunix.com.ar/~ldipenti/gwp/"),
+				_("A VGA Planets client for the GNOME platform.\nhttp://gwp.lunix.com.ar"),
 				(const gchar **)authors,
 				(const gchar **)documenters,
 				(const gchar *)translators,
@@ -642,6 +653,92 @@ gboolean delete_event (GtkWidget *widget,
   return TRUE;
 }
 
+/**
+ * Callback called when user wants to generate the TRN file.
+ */
+void on_maketurn_activate (GtkWidget *widget,
+			   gpointer user_data)
+{
+  gint commands;
+  GtkWidget *info;
+  gboolean apply_changes;
+
+  g_object_get (G_OBJECT(game_state),
+		"apply-changes", &apply_changes,
+		NULL);
+
+  /* Check if it's ok to apply changes to data files!! */
+  if (apply_changes) {
+    dump_to_dat_files();
+  } else {
+    GtkWidget *warn;
+    warn = gwp_warning_dialog_new (gwp,
+				   _("GWP won't apply your actions."),
+				   _("Although the turn file will be generated, your actions won't be reflected on it. You should change the appropriate setting on this game for this to happen."));
+    gtk_dialog_run (GTK_DIALOG(warn));
+    gtk_widget_destroy (warn);
+  }
+
+  /* Make the turn, baby yeaaahh! */
+  commands = vp_maketurn(gwp_game_state_get_dir(game_state),
+			 gwp_game_state_get_race_nr(game_state),
+			 gwp_game_state_get_trn_dir(game_state));
+  
+  info = gtk_message_dialog_new((GtkWindow*) gwp,
+				GTK_DIALOG_DESTROY_WITH_PARENT,
+				GTK_MESSAGE_INFO,
+				GTK_BUTTONS_CLOSE,
+				g_strdup_printf(_("Turn ready!\n%d commands done."), commands));
+  gtk_dialog_run(GTK_DIALOG(info));
+  gtk_widget_destroy(info);
+}
+
+/**
+ * Show game settings within GWP's main screen
+ */
+void
+on_game_settings_activate (GtkWidget *widget,
+			   gpointer   user_data)
+{
+  GtkWidget *ok_button = lookup_widget("game_mgr_button_ok");
+  GtkWidget *iconlist = lookup_widget("game_mgr_iconlist");
+  GtkWidget *btn_unpack = lookup_widget("game_mgr_btn_unpack");
+  GtkWidget *game_dir_entry = lookup_widget("game_mgr_game_dir");
+  GtkWidget *race_list = lookup_widget("game_mgr_properties_race_list");
+
+  if(game_mgr_properties_dlg_fill(game_state)) {
+    /* 
+     * Connect callback to OK button, so that works as 
+     * an "edit game" dialog. 
+     */
+      g_signal_connect(G_OBJECT(ok_button), 
+		       "clicked", 
+		       G_CALLBACK(game_mgr_cb_edit_game), 
+		       iconlist);
+      gtk_window_set_transient_for(GTK_WINDOW(game_mgr_properties), 
+				   GTK_WINDOW(gwp));
+      gtk_window_set_title(GTK_WINDOW(game_mgr_properties), 
+			   _("Edit Game Properties"));
+      
+      /* Disable some widgets that don't have to be changed */
+      gtk_widget_set_sensitive(btn_unpack, FALSE);
+      gtk_widget_set_sensitive(game_dir_entry, FALSE);
+      gtk_widget_set_sensitive(race_list, FALSE);
+      
+      gtk_widget_show(game_mgr_properties);
+  } else {
+    GtkWidget *warn;
+    
+    warn = gtk_message_dialog_new((GtkWindow*) game_mgr,
+				  GTK_DIALOG_DESTROY_WITH_PARENT,
+				  GTK_MESSAGE_WARNING,
+				  GTK_BUTTONS_CLOSE,
+				  _("Oops! there is some problem with this game"));
+    gtk_dialog_run(GTK_DIALOG(warn));
+    gtk_widget_destroy(warn);
+  }  
+}
+
 /*
  * Close current game and return to game manager.
  * FIXME: Here we'll have to clean all the data, including
@@ -658,19 +755,19 @@ void on_game_close_activate (GtkWidget *widget,
 void on_game_mgr_btn_unpack_clicked (GtkWidget *widget,
 				     gpointer user_data)
 {
-  GtkEntry *race_name_entry = 
-    (GtkEntry *) lookup_widget("game_mgr_entry_race_name");
   gint *race;
   gchar *game_dir;
+  GtkTreeView *race_l = (GtkTreeView *) 
+    lookup_widget("game_mgr_properties_race_list");
 
-  race = (gint *) g_object_get_data(G_OBJECT(race_name_entry),
+  race = (gint *) g_object_get_data(G_OBJECT(race_l),
 				    "race_number");
 
   game_dir = 
     gnome_file_entry_get_full_path((GnomeFileEntry *)
 				   lookup_widget("game_mgr_game_dir"),
 				   FALSE);
-  // Unpack this game
+  /* Unpack this game */
   vp_unpack(game_dir, *race);
 
   /* Disable button if all ok */
@@ -681,13 +778,68 @@ void on_game_mgr_btn_unpack_clicked (GtkWidget *widget,
   }
 }
 
-/* CB to format the hscale widgets value */
-gchar* on_hscale_tax_format_value(GtkScale *scale, gdouble value)
+/**
+ * Generate random planet Friendly Code
+ */
+void
+on_button_planet_fc_rand_clicked (GtkWidget *widget,
+				  gpointer   data)
 {
-  return g_strdup_printf("%0.*f%%", gtk_scale_get_digits(scale), value);
+  gchar *fc = g_malloc0 (sizeof(gchar)*4);
+  GwpPlanet *planet = gwp_game_state_get_selected_planet (game_state);
+  gint i;
+
+  for (i = 0; i < 3; i++) {
+    /* Random character between Space (32) and '~' (126) */
+    fc[i] = 32+(int) (94.0*rand()/(RAND_MAX+1.0));
+
+  }
+  fc[3] = '\0'; /* string termination */
+
+  gwp_planet_set_fcode (planet, fc);
+  g_free (fc);
 }
 
-/* Show online help */
+/**
+ * Tax change callback - natives.
+ */
+gboolean
+on_hscale_tax_natives_change_value  (GtkRange      *scale, 
+				     GtkScrollType  scroll,
+				     gdouble        value,
+				     gpointer       user_data)
+{
+  GwpPlanet *splanet = gwp_game_state_get_selected_planet (game_state);
+  gwp_planet_set_tax_natives (splanet, (gint)rint(value));
+
+  return FALSE;
+}
+/**
+ * Tax change callback - colonists.
+ */
+gboolean
+on_hscale_tax_colonists_change_value  (GtkRange      *scale, 
+				       GtkScrollType  scroll,
+				       gdouble        value,
+				       gpointer       user_data)
+{
+  GwpPlanet *splanet = gwp_game_state_get_selected_planet (game_state);
+  gwp_planet_set_tax_colonists (splanet, value);
+
+  return FALSE;
+}
+
+/**
+ * Callback to format the hscale widgets value 
+ */
+gchar* on_hscale_tax_format_value(GtkScale *scale, gdouble value)
+{
+  return g_strdup_printf("%0.*f%%", gtk_scale_get_digits(scale), rint(value));
+}
+
+/**
+ * Show online help 
+ */
 void on_online_help_activate (GtkWidget *widget,
 			      gpointer user_data)
 {
@@ -718,7 +870,9 @@ void on_button_zoom_out_clicked (GtkWidget *wodget,
   starchart_mini_update_zone_size ();
 }
 
-/* Zoom in */
+/**
+ * Zoom in 
+ */
 void 
 on_zoom_in (GtkWidget *widget,
 	    gpointer user_data)
@@ -729,7 +883,9 @@ on_zoom_in (GtkWidget *widget,
   starchart_mini_update_zone_size ();
 }
 
-/* Zoom out */
+/**
+ * Zoom out 
+ */
 void 
 on_zoom_out (GtkWidget *widget,
 	    gpointer user_data)
@@ -752,7 +908,9 @@ on_view_grid_toggle (GtkCheckMenuItem *menuitem,
 		NULL);
 }
 
-/* Hides/Shows the planet names on starchart */
+/**
+ * Hides/Shows the planet names on starchart 
+ */
 void on_view_pnames_activate (GtkCheckMenuItem *menuitem,
 			      gpointer user_data)
 {
@@ -761,7 +919,9 @@ void on_view_pnames_activate (GtkCheckMenuItem *menuitem,
 		NULL);
 }
 
-/* Hides/Shows the scanner area on starchart */
+/**
+ * Hides/Shows the scanner area on starchart 
+ */
 void on_view_scanner_area_activate (GtkCheckMenuItem *menuitem,
 				    gpointer user_data)
 {
@@ -770,7 +930,9 @@ void on_view_scanner_area_activate (GtkCheckMenuItem *menuitem,
 		NULL);  
 }
 
-/* Hides/Shows the minefields on starchart */
+/**
+ * Hides/Shows the minefields on starchart 
+ */
 void on_view_minefields_activate (GtkCheckMenuItem *menuitem,
 				  gpointer user_data)
 {
@@ -779,7 +941,9 @@ void on_view_minefields_activate (GtkCheckMenuItem *menuitem,
 		NULL);
 }
 
-/* Hides/Shows the ion storms on starchart */
+/**
+ * Hides/Shows the ion storms on starchart 
+ */
 void on_view_ion_storms_activate (GtkCheckMenuItem *menuitem,
 				  gpointer user_data)
 {
@@ -788,7 +952,9 @@ void on_view_ion_storms_activate (GtkCheckMenuItem *menuitem,
 		NULL);
 }
 
-/* Hides/Shows the constellations on starchart */
+/**
+ * Hides/Shows the constellations on starchart 
+ */
 void on_view_constellations_activate (GtkCheckMenuItem *menuitem,
 				      gpointer user_data)
 {
@@ -902,12 +1068,23 @@ g_message( "### 2: '%s'", gtk_tree_model_get_string_from_iter( model, &iter ) );
 */
 }
 
+/**
+ * Callback called when Friendly Code changed from main UI.
+ */
+void
+on_combo_planet_fc_changed (GtkComboBox *combobox,
+			    gpointer     user_data)
+{
+  GwpPlanet *planet = gwp_game_state_get_selected_planet (game_state);
+  GtkEntry *entry = GTK_ENTRY(GTK_BIN(combobox)->child);
+  gwp_planet_set_fcode (planet, g_strdup(gtk_entry_get_text(entry)));
+}
 
 /* Ship list double-click to open extra panels */
-void on_ships_list_row_activated (GtkTreeView *ships_l,
-				  GtkTreePath *path,
+void on_ships_list_row_activated (GtkTreeView       *ships_l,
+				  GtkTreePath       *path,
 				  GtkTreeViewColumn *col,
-				  gpointer user_data)
+				  gpointer           user_data)
 {
   GtkTreeModel *model = NULL;
   GtkTreeIter iter;
