@@ -1,6 +1,6 @@
 /*
  *  Gnome War Pad: A VGA Planets Client for Gnome
- *  Copyright (C) 2002,2003 Lucas Di Pentima <lucas@lunix.com.ar>
+ *  Copyright (C) 2002, 2005 Lucas Di Pentima <lucas@lunix.com.ar>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,6 +17,19 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+/** \file
+    $Source: /usr/local/cvs-publico/GWP/gwp/src/game_mgr.c,v $ 
+    $Revision: 1.63 $
+    
+    $Log: game_mgr.c,v $
+    Revision 1.63  2005/07/05 02:36:11  ldipenti
+    Feature: game property editor improved
+
+    Revision 1.62  2005/05/31 13:17:38  ldipenti
+    Feature: Added CVS metadata on source files
+
+*/
+
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -188,8 +201,8 @@ gboolean game_mgr_properties_dlg_fill(GwpGameState *settings)
 {
   GtkEntry *game_name = (GtkEntry *)
     lookup_widget("game_mgr_entry_game_name");
-  GtkEntry *race_name = (GtkEntry *)
-    lookup_widget("game_mgr_entry_race_name");
+  GtkTreeView *race_l = (GtkTreeView *) 
+    lookup_widget("game_mgr_properties_race_list");
   GtkEntry *player_email = (GtkEntry *)
     lookup_widget("game_mgr_entry_player_email");
   GtkEntry *host_email = (GtkEntry *)
@@ -200,7 +213,18 @@ gboolean game_mgr_properties_dlg_fill(GwpGameState *settings)
     lookup_widget("game_mgr_trn_dir");
   GnomeFileEntry *rst_dir = (GnomeFileEntry *)
     lookup_widget("game_mgr_rst_dir");
+  GtkRadioButton *radio_thost = 
+    (GtkRadioButton *) lookup_widget("radio_thost");
+  GtkRadioButton *radio_phost = 
+    (GtkRadioButton *) lookup_widget("radio_phost");
+  GtkCheckButton *chkbtn_apply_changes = 
+    (GtkCheckButton *) lookup_widget("game_mgr_checkbutton_apply_changes");
+  gboolean apply_changes = FALSE;
   gchar *game_name_str = g_strdup_printf("%s", gwp_game_state_get_name(settings));
+  GtkTreeSelection *selection = NULL;
+  GtkTreePath *path = NULL;
+  GtkTreeModel *model = NULL;
+  GtkTreeIter iter;
 
   game_mgr_game_name_demangle(game_name_str);
 
@@ -211,18 +235,49 @@ gboolean game_mgr_properties_dlg_fill(GwpGameState *settings)
   gtk_entry_set_text(game_name, game_name_str);
   gtk_entry_set_text(player_email, gwp_game_state_get_player_email(settings));
   gtk_entry_set_text(host_email, gwp_game_state_get_host_email(settings));
-  /* This MUST be after the game_dir changed event :-) */
-  gtk_entry_set_text(race_name, race_get_name(gwp_game_state_get_race(settings)));
+
   /* FIXME: this sucks */
   gint *racenum = g_malloc(sizeof(gint));
   *racenum = gwp_game_state_get_race_nr (settings);
-  g_object_set_data(G_OBJECT(race_name),
+  g_object_set_data(G_OBJECT(race_l),
 		    "race_number", racenum);
   g_object_set_data(G_OBJECT(game_name),
 		    "old_game_name", g_strdup(gwp_game_state_get_name(settings)));
 
-  /* FIXME: Remember host type!!! */
-  
+  /* Select correct race in available race list */
+  model = gtk_tree_view_get_model (race_l);
+  /* If tree is not empty... */
+  gint *race = g_malloc(sizeof(gint));
+  if (gtk_tree_model_get_iter_first (model, &iter)) {
+    do {
+      gtk_tree_model_get (model, &iter, 
+			  1, race, 
+			  -1);
+      /* If found, select it! */
+      if (*race == *racenum) {
+	path = gtk_tree_model_get_path (model, &iter);
+	selection = gtk_tree_view_get_selection (race_l);
+	gtk_tree_selection_select_path (selection, path);
+	break;
+      }
+    } while (gtk_tree_model_iter_next (model, &iter));
+  }
+
+  /* Host type: 0 is for old games */
+  if ((gwp_game_state_get_host_type(settings) == 0) ||
+      (gwp_game_state_get_host_type(settings) == 
+       GWP_GAME_STATE_HOST_TYPE_THOST))
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(radio_thost), TRUE);
+  else
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(radio_phost), TRUE);
+      
+  /* GWP should apply player's actions? */
+  g_object_get (G_OBJECT(settings), 
+		"apply-changes", &apply_changes,
+		NULL);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(chkbtn_apply_changes),
+				apply_changes);
+
   /* Do some validations... */
   if(game_mgr_properties_dlg_all_ok(FALSE, -1)) {
     return TRUE;
@@ -233,9 +288,9 @@ gboolean game_mgr_properties_dlg_fill(GwpGameState *settings)
 }
 
 
-/* 
+/**
  * Callback function connected to OK button on the game
- * properties dialog when using it as an edit game dialog
+ * properties dialog when using it as an edit game dialog.
  */
 void game_mgr_cb_edit_game(GtkWidget *widget, GtkWidget *iconlist)
 {
@@ -277,7 +332,7 @@ void game_mgr_cb_edit_game(GtkWidget *widget, GtkWidget *iconlist)
 
 /**
  * Callback function connected to OK button on the game 
- * properties dialog when using it as a new game dialog 
+ * properties dialog when using it as a new game dialog.
  */
 void game_mgr_cb_new_game(GtkWidget *widget, gpointer iconlist)
 {
@@ -330,8 +385,12 @@ void game_mgr_properties_dlg_get_settings(GwpGameState *settings)
     (GtkEntry *) lookup_widget("game_mgr_entry_player_email");
   GtkEntry *host_email =
     (GtkEntry *) lookup_widget("game_mgr_entry_host_email");
-  GtkEntry *race_name =
-    (GtkEntry *) lookup_widget("game_mgr_entry_race_name");
+  GtkTreeView *race_l = 
+    (GtkTreeView *) lookup_widget("game_mgr_properties_race_list");
+  GtkRadioButton *radio_thost = 
+    (GtkRadioButton *) lookup_widget("radio_thost");
+  GtkCheckButton *chkbtn_apply_changes = 
+    (GtkCheckButton *) lookup_widget("game_mgr_checkbutton_apply_changes");
   gint *race_num = NULL;
   gchar *name;
   
@@ -351,11 +410,20 @@ void game_mgr_properties_dlg_get_settings(GwpGameState *settings)
 				   g_strdup(gtk_entry_get_text(player_email)));
   gwp_game_state_set_host_email (settings, 
 				 g_strdup(gtk_entry_get_text(host_email)));
-  /* FIXME: settings->host_type = */
-  race_num = (gint *) g_object_get_data(G_OBJECT(race_name),
+  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_thost))) {
+    gwp_game_state_set_host_type (settings, GWP_GAME_STATE_HOST_TYPE_THOST);
+  } else {
+    gwp_game_state_set_host_type (settings, GWP_GAME_STATE_HOST_TYPE_PHOST);   
+  }
+  race_num = (gint *) g_object_get_data(G_OBJECT(race_l),
 					"race_number");
   g_assert(race_num != NULL);
   gwp_game_state_set_race (settings, *race_num);
+
+  /* Apply changes setting */
+  g_object_set (G_OBJECT(settings),
+		"apply-changes", gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(chkbtn_apply_changes)),
+		NULL);
 }
 
 /* Several dialog validations */
@@ -366,8 +434,8 @@ gboolean game_mgr_properties_dlg_all_ok(gboolean show_warnings,
     (GnomeFileEntry *) lookup_widget("game_mgr_game_dir");
   GtkEntry *game_name = 
     (GtkEntry *) lookup_widget("game_mgr_entry_game_name");
-  GtkEntry *race_name =
-    (GtkEntry *) lookup_widget("game_mgr_entry_race_name");
+  GtkTreeView *race_l = 
+    (GtkTreeView *) lookup_widget("game_mgr_properties_race_list");
   GnomeFileEntry *trn_dir =
     (GnomeFileEntry *) lookup_widget("game_mgr_trn_dir");
   GnomeFileEntry *rst_dir =
@@ -447,7 +515,7 @@ gboolean game_mgr_properties_dlg_all_ok(gboolean show_warnings,
   /*
    * Check if user selected a race 
    */
-  if(strlen(gtk_entry_get_text(race_name)) <= 0) {
+  if((gint)g_object_get_data(G_OBJECT(race_l), "race_number") <= 0) {
     if(show_warnings) {
       GtkWidget *warn;
       
@@ -486,15 +554,13 @@ void game_mgr_properties_dlg_clean(void)
 
   race_list = (GtkTreeView*) lookup_widget("game_mgr_properties_race_list");
   store = (GtkListStore*) gtk_tree_view_get_model(race_list);
+  gtk_widget_set_sensitive (GTK_WIDGET(race_list), TRUE);
   g_assert(store != NULL);
   gtk_list_store_clear(store);
   
   entry = (GtkEntry *) lookup_widget("game_mgr_entry_game_name");
   gtk_entry_set_text(entry, "");
 
-  entry = (GtkEntry *) lookup_widget("game_mgr_entry_race_name");
-  gtk_entry_set_text(entry, "");
-
   entry = (GtkEntry *) lookup_widget("game_mgr_entry_player_email");
   gtk_entry_set_text(entry, "");
 
@@ -509,6 +575,7 @@ void game_mgr_properties_dlg_clean(void)
 
   fentry = (GnomeFileEntry *) lookup_widget("game_mgr_game_dir");
   gnome_file_entry_set_filename(fentry, "");
+  gtk_widget_set_sensitive (GTK_WIDGET(fentry), TRUE);
 }
 
 /**
@@ -597,12 +664,13 @@ void game_mgr_play_game(GwpGameState *state)
   gchar *tmp;
   GtkLabel *race = 
     (GtkLabel *) lookup_widget("label_race_name");
+  gboolean warn_apply_changes = TRUE;
 
   /* If none game selected, notice the user */
   if (!state) {
     GtkWidget *warn;
 
-    warn = gwp_warning_dialog_new (game_mgr_properties,
+    warn = gwp_warning_dialog_new (game_mgr,
 				   _("No game selected, please select one."),
 				   _("If you don't have any game on your game manager, you should add one with the \"New\" button, adding the necessary game data."));
     gtk_dialog_run(GTK_DIALOG(warn));
@@ -612,6 +680,27 @@ void game_mgr_play_game(GwpGameState *state)
 
   game_state = state;
 
+  /* 
+   * Warn the player once about the new data modification features, 
+   * they may corrupt the game.
+   * FIXME: This should be temporary until it's finished and tested.
+   */
+  g_object_get (G_OBJECT(game_state),
+		"warn-apply-changes", &warn_apply_changes,
+		NULL);
+  if (warn_apply_changes) {
+    GtkWidget *warn;
+    warn = gwp_warning_dialog_new (game_mgr,
+				   _("GWP won't apply your actions by default."),
+				   _("New features are being added to GWP that allow to make some actions on the game.\nIt's possible that some bug can cause data corruption on your game, so this actions aren't being applied to the game files by default.\nYou can activate this by editing the game's properties, use this at your own risk!"));
+    gtk_dialog_run (GTK_DIALOG(warn));
+    gtk_widget_destroy (warn);
+    /* Do not bother the user again */
+    g_object_set (G_OBJECT(game_state),
+		  "warn-apply-changes", FALSE,
+		  NULL);
+  }
+
   /* Check for new RST */
   if (vp_can_unpack(gwp_game_state_get_dir(game_state), 
 		    gwp_game_state_get_race(game_state))) {
@@ -873,14 +962,41 @@ GwpGameState * game_mgr_load_game_state (gchar *games_path, gchar *game_name)
 				      NULL),
 		NULL);
 
-  g_object_set (game, 
-		"warn-korefile", 
-		gconf_client_get_bool(gwp_gconf, 
-				      g_strconcat (path, 
-						   "warn-korefile", 
-						   NULL),
-				      NULL),
-		NULL);
+  /* If key is present, assign its value, if not...let the default be! */
+  if (gconf_client_get(gwp_gconf, g_strconcat(path, "warn-korefile", NULL), NULL)) {
+    g_object_set (game, 
+		  "warn-korefile", 
+		  gconf_client_get_bool(gwp_gconf, 
+					g_strconcat (path, 
+						     "warn-korefile", 
+						     NULL),
+					NULL),
+		  NULL);
+  }
+
+  /* If key is present, assign its value, if not...let the default be! */
+  if (gconf_client_get(gwp_gconf, g_strconcat(path, "apply-changes", NULL), NULL)) {
+    g_object_set (game, 
+		  "apply-changes", 
+		  gconf_client_get_bool(gwp_gconf, 
+					g_strconcat (path, 
+						     "apply-changes", 
+						     NULL),
+					NULL),
+		  NULL);
+  }
+
+  /* If key is present, assign its value, if not...let the default be! */
+  if (gconf_client_get(gwp_gconf, g_strconcat(path, "warn-apply-changes", NULL), NULL)) {
+    g_object_set (game, 
+		  "warn-apply-changes", 
+		  gconf_client_get_bool(gwp_gconf, 
+					g_strconcat (path, 
+						     "warn-apply-changes", 
+						     NULL),
+					NULL),
+		  NULL);
+  }
 
   /* Registered plugins */
   GSList *plugins = gconf_client_get_list (gwp_gconf,
@@ -963,6 +1079,15 @@ void game_mgr_save_game_state (GwpGameState *state, gboolean closing_game)
   gconf_client_set_bool (gwp_gconf, g_strconcat(path, "warn-korefile", NULL),
 			 tmp_bool, NULL);
 
+  g_object_get (G_OBJECT(state), "apply-changes", &tmp_bool, NULL);
+  gconf_client_set_bool (gwp_gconf, g_strconcat(path, "apply-changes", NULL),
+			 tmp_bool, NULL);
+
+  g_object_get (G_OBJECT(state), "warn-apply-changes", &tmp_bool, NULL);
+  gconf_client_set_bool (gwp_gconf, 
+			 g_strconcat(path, "warn-apply-changes", NULL),
+			 tmp_bool, NULL);
+
 #ifdef USE_PYTHON
   if (closing_game) {
     /* Registered plugins */
@@ -974,7 +1099,6 @@ void game_mgr_save_game_state (GwpGameState *state, gboolean closing_game)
 #endif
 }
 
-
 /**
  * Deletes GConf Game entry... 
  */
@@ -1019,10 +1143,19 @@ void game_mgr_close_game(GwpGameState *game_state)
 {
   if(game_state) {
     gint x, y, i;
+    gboolean apply_changes;
 
     /* Save game state */
     gnome_canvas_get_scroll_offsets(starchart_get_canvas(), &x, &y);
     gwp_game_state_set_last_coords(game_state, x, y);
+
+    /* Check if it's ok to apply changes to data files!! */
+    g_object_get (G_OBJECT(game_state),
+		  "apply-changes", &apply_changes,
+		  NULL);
+    if (apply_changes)
+      dump_to_dat_files();
+    
     game_mgr_save_game_state(game_state, TRUE);
 
     /******************************/
