@@ -17,6 +17,16 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+/** \file
+    $Source: /usr/local/cvs-publico/GWP/gwp/src/gwp-planet.c,v $ 
+    $Revision: 1.45 $
+    
+    $Log: gwp-planet.c,v $
+    Revision 1.45  2005/05/31 13:17:38  ldipenti
+    Feature: Added CVS metadata on source files
+
+*/
+
 #include <math.h>
 #include <string.h>
 
@@ -30,6 +40,15 @@
 gint gwp_planet_mineral_extraction_rate(GwpPlanet *self, gint density, gint mineral);
 gint gwp_planet_mineral_turns_left(gint mineral, gint extraction_rate);
 
+enum {
+  PROP_0,
+  PROP_TAX_NATIVES,
+  PROP_TAX_COLONISTS,
+  PROP_FCODE,
+  PROP_MINES,
+  PROP_FACTORIES,
+  PROP_DEFENSE_POSTS,
+};
 
 /**
  * Private data structure for the GwpPlanet type.
@@ -46,10 +65,11 @@ struct _GwpPlanetPrivate {
   gint16 owner; /**< Owner's race number. Range 1..11. 0 = unowned, -1
 		   = unknown */
   GString *fcode; /**< Planet's friendly Code. Max 3 chars. */
-  gint16 mines; /**< Mineral mines on planet. */
-  gint16 factories; /**< Supplies factories on planet. */
+  gint16 mines; /**< Mineral mines on planet. (0..~516) */
+  gint16 factories; /**< Supplies factories on planet. (0..~416) */
   gint16 defense_posts; /**< Defense posts on planet. If 15 or more,
-			   planet activity's visibility goes to 0% */
+			   planet activity's visibility goes to 0%. 
+			   (0..~366) */
   gint32 mined_neutronium; /**< Neutronium on surface. Specified in KT. */
   gint32 mined_tritanium; /**< Tritanium on surface. Specified in KT. */
   gint32 mined_duranium; /**< Duranium on surface. Specified in KT. */
@@ -198,6 +218,82 @@ static void gwp_planet_init (GTypeInstance *instance,
   self->priv->build_base = 0;
 }
 
+/**
+ * Property setters
+ */
+static void
+gwp_planet_set_property (GObject      *object,
+			 guint         property_id,
+			 const GValue *value,
+			 GParamSpec   *pspec)
+{
+  GwpPlanet *self = (GwpPlanet *) object;
+
+  switch (property_id) {
+  case PROP_TAX_NATIVES:
+    self->priv->tax_natives = g_value_get_int (value);
+    break;
+  case PROP_TAX_COLONISTS:
+    self->priv->tax_colonists = g_value_get_int (value);
+    break;
+  case PROP_FCODE:
+    if (strlen (g_value_get_string(value)) <= 3)
+      self->priv->fcode = g_string_new (g_value_get_string(value));
+    break;
+  case PROP_MINES:
+    self->priv->mines = g_value_get_int (value);
+    break;
+  case PROP_FACTORIES:
+    self->priv->factories = g_value_get_int (value);
+    break;
+  case PROP_DEFENSE_POSTS:
+    self->priv->defense_posts = g_value_get_int (value);
+    break;
+  default:
+    G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+    break;
+  }
+  /* Emit a notify signal with the changed property name */
+  g_signal_emit_by_name (self, g_strconcat("property-changed::",
+					   pspec->name, NULL));
+}
+
+/**
+ * Property getters
+ */
+static void
+gwp_planet_get_property (GObject    *object,
+			 guint       property_id,
+			 GValue     *value,
+			 GParamSpec *pspec)
+{
+  GwpPlanet *self = (GwpPlanet *) object;
+
+  switch (property_id) {
+  case PROP_TAX_NATIVES:
+    g_value_set_int (value, self->priv->tax_natives);
+    break;
+  case PROP_TAX_COLONISTS:
+    g_value_set_int (value, self->priv->tax_colonists);
+    break;
+  case PROP_FCODE:
+    g_value_set_string (value, self->priv->fcode->str);
+    break;
+  case PROP_MINES:
+    g_value_set_int (value, self->priv->mines);
+    break;
+  case PROP_FACTORIES:
+    g_value_set_int (value, self->priv->factories);
+    break;
+  case PROP_DEFENSE_POSTS:
+    g_value_set_int (value, self->priv->defense_posts);
+    break;
+  default:
+    G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+    break;    
+  }
+}
+
 static void gwp_planet_dispose (GwpPlanet *self)
 {
   if (self->priv->dispose_has_run) {
@@ -244,6 +340,64 @@ static void gwp_planet_class_init (GwpPlanetClass *klass)
 		 G_TYPE_NONE /* return_type */,
 		 0     /* n_params */,
 		 NULL  /* param_types */);
+
+  g_signal_newv ("property-changed",
+		 G_TYPE_FROM_CLASS (klass),
+		 G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
+		 NULL /* class closure */,
+		 NULL /* accumulator */,
+		 NULL /* accu_data */,
+		 g_cclosure_marshal_VOID__VOID,
+		 G_TYPE_NONE /* return_type */,
+		 0     /* n_params */,
+		 NULL  /* param_types */);
+
+  /* Property get/set methods */
+  gobject_class->set_property = gwp_planet_set_property;
+  gobject_class->get_property = gwp_planet_get_property;
+
+  /* Properties registrations */
+  g_object_class_install_property (gobject_class, PROP_TAX_NATIVES,
+				   g_param_spec_int ("tax-natives",
+						     "Tax-Natives",
+						     "Native's Taxes",
+						     0, 100, /* min/max */
+						     0, /* default */
+						     G_PARAM_READWRITE));
+  g_object_class_install_property (gobject_class, PROP_TAX_COLONISTS,
+				   g_param_spec_int ("tax-colonists",
+						     "Tax-Colonists",
+						     "Colonists's Taxes",
+						     0, 100, /* min/max */
+						     0, /* default */
+						     G_PARAM_READWRITE));
+  g_object_class_install_property (gobject_class, PROP_FCODE,
+				   g_param_spec_string ("fcode",
+							"fc",
+							"Friendly Code",
+							"GWP", /* default */
+							G_PARAM_READWRITE));
+  g_object_class_install_property (gobject_class, PROP_MINES,
+				   g_param_spec_int ("mines",
+						     "Mines",
+						     "Mineral mines",
+						     0, 516, /* min/max */
+						     0, /* default */
+						     G_PARAM_READWRITE));
+  g_object_class_install_property (gobject_class, PROP_FACTORIES,
+				   g_param_spec_int ("factories",
+						     "Factories",
+						     "Supplies factories",
+						     0, 416, /* min/max */
+						     0, /* default */
+						     G_PARAM_READWRITE));
+  g_object_class_install_property (gobject_class, PROP_DEFENSE_POSTS,
+				   g_param_spec_int ("defense-posts",
+						     "Defense-Posts",
+						     "Defense Posts",
+						     0, 366, /* min/max */
+						     0, /* default */
+						     G_PARAM_READWRITE));
 }
 
 /**
@@ -256,6 +410,7 @@ GwpPlanet * gwp_planet_new (void)
   return g_object_new (gwp_planet_get_type(), NULL);
 }
 
+
 /**********************/
 /* High-level methods */
 /**********************/
@@ -1024,7 +1179,9 @@ void gwp_planet_set_is_known (GwpPlanet *self, gboolean is_known)
 GwpStarbase * gwp_planet_get_starbase (GwpPlanet *self)
 {
   g_assert (GWP_IS_PLANET(self));
-  g_assert (GWP_IS_STARBASE(self->priv->starbase));
+  if (self->priv->starbase) {
+    g_return_val_if_fail (GWP_IS_STARBASE(self->priv->starbase), NULL);
+  }
   return self->priv->starbase;
 }
 
@@ -1051,57 +1208,81 @@ void gwp_planet_set_owner (GwpPlanet *self, gint16 o)
 gchar * gwp_planet_get_fcode (GwpPlanet *self)
 {
   g_assert (GWP_IS_PLANET(self));
-  GString *ret = g_string_new(self->priv->fcode->str);
+  gchar *ret = NULL;
+  
+  g_object_get (self,
+		"fcode", &ret,
+		NULL);
 
-  return ret->str;
+  return g_strdup(ret);
 }
 
 void gwp_planet_set_fcode (GwpPlanet *self, gchar *fcode)
 {
   g_assert (GWP_IS_PLANET(self));
-  
-  if (strlen(fcode) <= 3) {
-    self->priv->fcode = g_string_new (fcode);
-  }
+  g_object_set (self,
+		"fcode", g_strdup(fcode),
+		NULL);
 }
 
 gint16 gwp_planet_get_mines (GwpPlanet *self)
 {
   g_assert (GWP_IS_PLANET(self));
-  return self->priv->mines;
+  gint mines;
+  
+  g_object_get (self,
+		"mines", &mines,
+		NULL);
+
+  return mines;
 }
 
 void gwp_planet_set_mines (GwpPlanet *self, gint16 m)
 {
   g_assert (GWP_IS_PLANET(self));
-  g_assert (m >= 0 && m <= 516);
-  self->priv->mines = m;
+  g_object_set (self,
+		"mines", m,
+		NULL);
 }
 
 gint16 gwp_planet_get_factories (GwpPlanet *self)
 {
   g_assert (GWP_IS_PLANET(self));
-  return self->priv->factories;
+  gint factories;
+
+  g_object_get (self,
+		"factories", &factories,
+		NULL);
+
+  return factories;
 }
 
 void gwp_planet_set_factories (GwpPlanet *self, gint16 f)
 {
   g_assert (GWP_IS_PLANET(self));
-  g_assert (f >= 0 && f <= 416);
-  self->priv->factories = f;
+  g_object_set (self,
+		"factories", f,
+		NULL);
 }
 
 gint16 gwp_planet_get_defense_posts (GwpPlanet *self)
 {
   g_assert (GWP_IS_PLANET(self));
-  return self->priv->defense_posts;
+  gint defense_posts;
+
+  g_object_get (self,
+		"defense-posts", &defense_posts,
+		NULL);
+
+  return defense_posts;
 }
 
 void gwp_planet_set_defense_posts (GwpPlanet *self, gint16 d)
 {
   g_assert (GWP_IS_PLANET(self));
-  g_assert (d >= 0 && d <= 366);
-  self->priv->defense_posts = d;
+  g_object_set (self,
+		"defense-posts", d,
+		NULL);
 }
 
 gint32 gwp_planet_get_mined_neutronium (GwpPlanet *self)
@@ -1302,14 +1483,21 @@ void gwp_planet_set_dens_molybdenum (GwpPlanet *self, gint16 dm)
 gint16 gwp_planet_get_tax_colonists (GwpPlanet *self)
 {
   g_assert (GWP_IS_PLANET(self));
-  return self->priv->tax_colonists;
+  gint ret;
+
+  g_object_get (self,
+		"tax_colonists", &ret,
+		NULL);
+
+  return ret;
 }
 
 void gwp_planet_set_tax_colonists (GwpPlanet *self, gint16 tc)
 {
   g_assert (GWP_IS_PLANET(self));
-  g_assert (tc >= 0);
-  self->priv->tax_colonists = tc;
+  g_object_set (self,
+		"tax-colonists", tc,
+		NULL);
 }
 
 gint16 gwp_planet_get_tax_natives (GwpPlanet *self)
@@ -1321,8 +1509,9 @@ gint16 gwp_planet_get_tax_natives (GwpPlanet *self)
 void gwp_planet_set_tax_natives (GwpPlanet *self, gint16 tn)
 {
   g_assert (GWP_IS_PLANET(self));
-  g_assert (tn >= 0);
-  self->priv->tax_natives = tn;
+  g_object_set (self,
+		"tax-natives", tn,
+		NULL);
 }
 
 gint16 gwp_planet_get_happiness_colonists (GwpPlanet *self)
