@@ -17,6 +17,16 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+/** \file
+    $Source: /usr/local/cvs-publico/GWP/gwp/src/gwp-python.h,v $ 
+    $Revision: 1.7 $
+    
+    $Log: gwp-python.h,v $
+    Revision 1.7  2005/05/31 13:17:39  ldipenti
+    Feature: Added CVS metadata on source files
+
+*/
+
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
