@@ -17,6 +17,16 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+/** \file
+    $Source: /usr/local/cvs-publico/GWP/gwp/src/gwp-ship.c,v $ 
+    $Revision: 1.37 $
+    
+    $Log: gwp-ship.c,v $
+    Revision 1.37  2005/05/31 13:17:39  ldipenti
+    Feature: Added CVS metadata on source files
+
+*/
+
 #include <math.h>
 
 #include "global.h"
@@ -1201,7 +1211,7 @@ gint16 gwp_ship_get_tow_ship_id (GwpShip *self)
 void gwp_ship_set_tow_ship_id (GwpShip *self, gint16 id)
 {
   g_assert (GWP_IS_SHIP(self));
-  g_assert (id >= 0 && id <= 500); /* FIXME: check for Host999! */
+  g_assert (id >= 0 && id <= 999); /* FIXME: check for Host999! */
   self->priv->tow_ship_id = id;
 }
 
@@ -1444,7 +1454,7 @@ void gwp_ship_set_transfer_duranium (GwpShip *self, gint16 dur)
 gint16 gwp_ship_get_transfer_molybdenum (GwpShip *self)
 {
   g_assert (GWP_IS_SHIP(self));
-  return self->priv->molybdenum;
+  return self->priv->transfer_molybdenum;
 }
 
 void gwp_ship_set_transfer_molybdenum (GwpShip *self, gint16 mol)
@@ -1489,7 +1499,7 @@ gint16 gwp_ship_get_transfer_ship_id (GwpShip *self)
 void gwp_ship_set_transfer_ship_id (GwpShip *self, gint16 sid)
 {
   g_assert (GWP_IS_SHIP(self));
-  g_assert (sid >= 0 && sid <= 500); /* FIXME: check for Host999 and if not 0, the ship is on the same spot */
+  g_assert (sid >= 0 && sid <= 999); /* FIXME: check for Host999 and if not 0, the ship is on the same spot */
   self->priv->transfer_ship_id = sid;
 }
 
@@ -1502,7 +1512,7 @@ gint16 gwp_ship_get_intercept_ship_id (GwpShip *self)
 void gwp_ship_set_intercept_ship_id (GwpShip *self, gint16 sid)
 {
   g_assert (GWP_IS_SHIP(self));
-  g_assert (sid >= 0 && sid <= 500); /* FIXME: check for Host999 and if not 0, the ship should be on the same spot */
+  g_assert (sid >= 0 && sid <= 999); /* FIXME: check for Host999 and if not 0, the ship should be on the same spot */
   self->priv->intercept_ship_id = sid;
 }
 
