@@ -1,3 +1,12 @@
+/** \file
+    $Source: /usr/local/cvs-publico/GWP/gwp/src/message-reader.c,v $ 
+    $Revision: 1.16 $
+    
+    $Log: message-reader.c,v $
+    Revision 1.16  2005/05/31 13:17:39  ldipenti
+    Feature: Added CVS metadata on source files
+
+*/
 
 #include <gnome.h>
 #include <math.h>
