@@ -17,6 +17,16 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+/** \file
+    $Source: /usr/local/cvs-publico/GWP/gwp/src/tables.h,v $ 
+    $Revision: 1.3 $
+    
+    $Log: tables.h,v $
+    Revision 1.3  2005/05/31 13:17:39  ldipenti
+    Feature: Added CVS metadata on source files
+
+*/
+
 #ifndef TABLES_H
 #define TABLES_H
 
