@@ -1,3 +1,12 @@
+/** \file
+    $Source: /usr/local/cvs-publico/GWP/gwp/src/vcr-combat-gl.c,v $ 
+    $Revision: 1.16 $
+    
+    $Log: vcr-combat-gl.c,v $
+    Revision 1.16  2005/05/31 13:17:39  ldipenti
+    Feature: Added CVS metadata on source files
+
+*/
 
 #define USE_TEXTURES
 
