@@ -1,3 +1,13 @@
+/** \file
+    $Source: /usr/local/cvs-publico/GWP/gwp/src/vcr-combat-gl.h,v $ 
+    $Revision: 1.9 $
+    
+    $Log: vcr-combat-gl.h,v $
+    Revision 1.9  2005/05/31 13:17:39  ldipenti
+    Feature: Added CVS metadata on source files
+
+*/
+
 #ifndef VCR_COMBAT_GL_H
 #define VCR_COMBAT_GL_H
 
