@@ -1,3 +1,13 @@
+/** \file
+    $Source: /usr/local/cvs-publico/GWP/gwp/src/vcr-combat.c,v $ 
+    $Revision: 1.16 $
+    
+    $Log: vcr-combat.c,v $
+    Revision 1.16  2005/05/31 13:17:39  ldipenti
+    Feature: Added CVS metadata on source files
+
+*/
+
 #include "vcr-combat-gl.h"
 #include "vcr-combat.h"
 #include "vcr.h"
